species
=======

**spectral and photometric examination code for investigating exoplanet and substellar atmospheres**

.. image:: https://badge.fury.io/py/species.svg
    :target: https://badge.fury.io/py/species

.. image:: https://img.shields.io/badge/Python-3.6%2C%203.7-yellow.svg?style=flat
    :target: https://pypi.python.org/pypi/species

.. image:: https://travis-ci.org/tomasstolker/species.svg?branch=master
    :target: https://travis-ci.org/tomasstolker/species

.. image:: https://readthedocs.org/projects/species/badge/?version=latest
    :target: http://species.readthedocs.io/en/latest/?badge=latest

.. image:: https://coveralls.io/repos/github/tomasstolker/species/badge.svg
   :target: https://coveralls.io/github/tomasstolker/species

.. image:: https://www.codefactor.io/repository/github/tomasstolker/species/badge
   :target: https://www.codefactor.io/repository/github/tomasstolker/species

.. image:: https://img.shields.io/badge/License-GPLv3-blue.svg
    :target: https://github.com/tomasstolker/species/blob/master/LICENSE

*species* is a toolkit for analyzing spectral and photometric data of planetary and substellar objects. It provides a coherent framework for atmospheric characterization which builds on publicly-available data from various resources such as spectral and photometric libraries, atmospheric models, photometry of individual targets, and filter transmission curves. All data are stored in a central database and there are tools available for creating color-magnitude diagrams, fitting atmospheric models and retrieving the posterior distributions, creating synthetic photometry, plotting spectra, etc. The package has been released on `PyPI <https://pypi.org/project/species/>`_ but is still under active development.

Documentation
-------------

Documentation can be found at `http://species.readthedocs.io <http://species.readthedocs.io>`_.

Attribution
-----------

Please cite Stolker et al. in prep. whenever results from *species* are used in a publication. Please also make sure to give credit to the relevant papers regarding the use of the publicly available data that *species* is profiting from. More details will follow.

Contributing
------------

Contributions are very welcome, please consider forking the repository and creating a pull request. Bug reports can be provided by creating an `issue <https://github.com/tomasstolker/species/issues>`_ on the Github page.

License
-------

Copyright 2019 Tomas Stolker

*species* is distributed under the GNU General Public License v3. See the LICENSE file for the terms and conditions.